@@ -1,3 +1,4 @@
+from logging import warning
 from math import ceil, log
 
 import torch
@@ -764,8 +765,15 @@ class CornerHead(BaseDenseHead):
     def _bboxes_nms(self, bboxes, labels, cfg):
         if labels.numel() == 0:
             return bboxes, labels
+
+        if 'nms_cfg' in cfg:
+            warning.warn('nms_cfg in test_cfg will be deprecated. '
+                         'Please rename it as nms')
+        if 'nms' not in cfg:
+            cfg.nms = cfg.nms_cfg
+
         out_bboxes, keep = batched_nms(bboxes[:, :4], bboxes[:, -1], labels,
-                                       cfg.nms_cfg)
+                                       cfg.nms)
         out_labels = labels[keep]
 
         if len(out_bboxes) > 0:
